import os
import json

# from jupyter_server.base.handlers import APIHandler
from notebook.base.handlers import APIHandler
# from jupyter_server.utils import url_path_join
from notebook.utils import url_path_join

import tornado
from tornado.web import StaticFileHandler

class RouteHandler(APIHandler):
    # The following decorator should be present on all verb methods (head, get, post,
    # patch, put, delete, options) to ensure only authorized user can request the
    # Jupyter server
    @tornado.web.authenticated
    def get(self):
        profile_name = os.environ.get('OPENSARLAB_PROFILE_NAME', 'No environment variable "OPENSARLAB_PROFILE_NAME" found!')
        self.finish(json.dumps({"data": profile_name}))


def setup_handlers(web_app, url_path):
    host_pattern = ".*$"
    base_url = web_app.settings["base_url"]

    # Prepend the base_url so that it works in a JupyterHub setting
    route_pattern = url_path_join(base_url, url_path, "opensarlab-profile-label")
    handlers = [(route_pattern, RouteHandler)]
    web_app.add_handlers(host_pattern, handlers)

    # Prepend the base_url so that it works in a JupyterHub setting
    doc_url = url_path_join(base_url, url_path, "public")
    doc_dir = os.getenv(
        "OPENSARLAB_PROFILE_LABEL_STATIC_DIR",
        os.path.join(os.path.dirname(__file__), "public"),
    )
    handlers = [("{}/(.*)".format(doc_url), StaticFileHandler, {"path": doc_dir})]
    web_app.add_handlers(".*$", handlers)
